==> autonomize_autorag-0.1.19.tar.gz: autonomize_autorag-0.1.19/autorag/embedding/modelhub.py <==
"""Modelhub Embedding module implementation"""

# pylint: disable=line-too-long

from typing import Any, List, Literal, Union, override

import httpx

from autorag.core.credential import ModelhubCredential
from autorag.embedding.base import Embedding
from autorag.utilities.logger import get_logger

logger = get_logger()


class ModelhubEmbedding(Embedding):
    """
    Modelhub Embedding implementation.

    This class provides an implementation of the Embedding abstract class
    using our internal Modelhub SDK's embedding models to generate embeddings.

    Example:
    .. code-block:: python

        from autorag.core.credential import ModelhubCredential
        from autorag.embedding.modelhub import ModelhubEmbedding

        model_name = "bge_base"
        credential = ModelhubCredential(client_id="modelhub-client", client_secret="xxx")
        model = ModelhubEmbedding(
            credential=credential
        )

        model.create_embedding("Sample text", model_name=model_name)
    """

    MODEL_URL = (
        "https://clinical-llm.modelhub.sprint.autonomize.dev/v1/model/embedding/predict"
    )

    def __init__(self, credential: ModelhubCredential):
        """
        Initialize the ModelhubEmbedding instance.

        Args:
            credential ModelhubCredential: The credential object for authorizing with Modelhub
        """
        self._credential = credential

    def _create_embedding(
        self,
        texts: List[str],
        model_name: Literal[
            "bge_base",
            "bge_large",
        ] = "bge_base",
        **kwargs: Any,
    ) -> List[List[float]]:
        """
        Creates embeddings for the provided text(s) using the Modelhub embedding model.

        Args:
            texts (List[str]): The input list of texts to generate embeddings for.
            model_name (str): Modelhub embedding model name. Defaults to "bge_base".
            kwargs (Any): Any additional arguments to be used.

        Returns:
            List[List[float]]: A list of embedding vectors for the input texts.
        """
        token = self._credential.get_token()
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {token}",
        }

        payload = {"texts": texts, "model_name": model_name}

        # Setting verify=False, so our client doesn't check for SSL certificate.
        with httpx.Client(verify=False) as client:
            response = client.post(self.MODEL_URL, headers=headers, json=payload)
            response.raise_for_status()
            return response.json()["prediction"]

    @override
    async def acreate_embedding(
        self,
        texts: Union[str, List[str]],
        model_name: Literal[
            "bge_base",
            "bge_large",
        ] = "bge_base",
        **kwargs: Any,
    ) -> List[List[float]]:
        """
        Asynchronously creates embeddings for the provided text(s) using the Modelhub embedding model.

        Args:
            texts (Union[str, List[str]]): The input text or list of texts to generate embeddings for.
            model_name (str): Modelhub embedding model name. Defaults to "bge_base".
            kwargs (Any): Any additional arguments to be used.

        Returns:
            List[List[float]]: A list of embedding vectors for the input text(s).
        """
        token = await self._credential.aget_token()
        if isinstance(texts, str):
            texts = [texts]

        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {token}",
        }

        payload = {"texts": texts, "model_name": model_name}

        # Setting verify=False, so our client doesn't check for SSL certificate.
        async with httpx.AsyncClient(verify=False) as client:
            response = await client.post(self.MODEL_URL, headers=headers, json=payload)
            response.raise_for_status()
            return response.json()["prediction"]

==> autonomize_autorag-0.1.28.tar.gz: autonomize_autorag-0.1.28/autorag/embedding/modelhub.py <==
"""Modelhub Embedding module implementation"""

# pylint: disable=line-too-long, duplicate-code

from typing import Any, List, Literal, Union, override

import httpx

from autorag.core.credential import ModelhubCredential
from autorag.embedding.base import Embedding
from autorag.utilities.logger import get_logger

logger = get_logger()


class ModelhubEmbedding(Embedding):
    """
    Modelhub Embedding implementation.

    This class provides an implementation of the Embedding abstract class
    using our internal Modelhub SDK's embedding models to generate embeddings.

    Example:
    .. code-block:: python

        from autorag.core.credential import ModelhubCredential
        from autorag.embedding import ModelhubEmbedding

        model_name = "bge_base"
        credential = ModelhubCredential(client_id="modelhub-client", client_secret="xxx")
        model = ModelhubEmbedding(
            credential=credential
        )

        model.create_embedding("Sample text", model_name=model_name)
    """

    MODEL_URL = (
        "https://clinical-llm.modelhub.sprint.autonomize.dev/v1/model/embedding/predict"
    )

    def __init__(self, credential: ModelhubCredential):
        """
        Initialize the ModelhubEmbedding instance.

        Args:
            credential ModelhubCredential: The credential object for authorizing with Modelhub.
        """
        self._credential = credential

    def _create_embedding(
        self,
        texts: List[str],
        model_name: Literal[
            "bge_base",
            "bge_large",
        ] = "bge_base",
        **kwargs: Any,
    ) -> List[List[float]]:
        """
        Creates embeddings for the provided text(s) using the Modelhub embedding model.

        Args:
            texts (List[str]): The input list of texts to generate embeddings for.
            model_name (str): Modelhub embedding model name. Defaults to "bge_base".
            kwargs (Any): Any additional arguments to be used.

        Returns:
            List[List[float]]: A list of embedding vectors for the input texts.
        """
        token = self._credential.get_token()
        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {token}",
        }

        payload = {"texts": texts, "model_name": model_name}

        # Setting verify=False, so our client doesn't check for SSL certificate.
        with httpx.Client(verify=False) as client:
            response = client.post(self.MODEL_URL, headers=headers, json=payload)
            response.raise_for_status()
            return response.json()["prediction"]

    @override
    async def acreate_embedding(
        self,
        texts: Union[str, List[str]],
        model_name: Literal[
            "bge_base",
            "bge_large",
        ] = "bge_base",
        **kwargs: Any,
    ) -> List[List[float]]:
        """
        Asynchronously creates embeddings for the provided text(s) using the Modelhub embedding model.

        Args:
            texts (Union[str, List[str]]): The input text or list of texts to generate embeddings for.
            model_name (str): Modelhub embedding model name. Defaults to "bge_base".
            kwargs (Any): Any additional arguments to be used.

        Returns:
            List[List[float]]: A list of embedding vectors for the input text(s).
        """
        token = await self._credential.aget_token()
        if isinstance(texts, str):
            texts = [texts]

        headers = {
            "Content-Type": "application/json",
            "Authorization": f"Bearer {token}",
        }

        payload = {"texts": texts, "model_name": model_name}

        # Setting verify=False, so our client doesn't check for SSL certificate.
        async with httpx.AsyncClient(verify=False) as client:
            response = await client.post(self.MODEL_URL, headers=headers, json=payload)
            response.raise_for_status()
            return response.json()["prediction"]
